@@ -37,7 +37,7 @@ ConflictResolver::ConflictResolver(QWidget *parentWidget, QObject *parent)
     , mWeekdays(7)
     , mSlotResolutionSeconds(DEFAULT_RESOLUTION_SECONDS)
 {
-    const KDateTime currentLocalDateTime = KDateTime::currentLocalDateTime();
+    const QDateTime currentLocalDateTime = QDateTime::currentDateTime();
     mTimeframeConstraint = KCalCore::Period(currentLocalDateTime, currentLocalDateTime);
 
     // trigger a reload in case any attendees were inserted before
@@ -99,7 +99,7 @@ bool ConflictResolver::containsAttendee(const KCalCore::Attendee::Ptr &attendee)
 
 void ConflictResolver::setEarliestDate(const QDate &newDate)
 {
-    KDateTime newStart = mTimeframeConstraint.start();
+    QDateTime newStart = mTimeframeConstraint.start();
     newStart.setDate(newDate);
     mTimeframeConstraint = KCalCore::Period(newStart, mTimeframeConstraint.end());
     calculateConflicts();
@@ -107,7 +107,7 @@ void ConflictResolver::setEarliestDate(const QDate &newDate)
 
 void ConflictResolver::setEarliestTime(const QTime &newTime)
 {
-    KDateTime newStart = mTimeframeConstraint.start();
+    QDateTime newStart = mTimeframeConstraint.start();
     newStart.setTime(newTime);
     mTimeframeConstraint = KCalCore::Period(newStart, mTimeframeConstraint.end());
     calculateConflicts();
@@ -115,7 +115,7 @@ void ConflictResolver::setEarliestTime(const QTime &newTime)
 
 void ConflictResolver::setLatestDate(const QDate &newDate)
 {
-    KDateTime newEnd = mTimeframeConstraint.end();
+    QDateTime newEnd = mTimeframeConstraint.end();
     newEnd.setDate(newDate);
     mTimeframeConstraint = KCalCore::Period(mTimeframeConstraint.start(), newEnd);
     calculateConflicts();
@@ -123,19 +123,19 @@ void ConflictResolver::setLatestDate(const QDate &newDate)
 
 void ConflictResolver::setLatestTime(const QTime &newTime)
 {
-    KDateTime newEnd = mTimeframeConstraint.end();
+    QDateTime newEnd = mTimeframeConstraint.end();
     newEnd.setTime(newTime);
     mTimeframeConstraint = KCalCore::Period(mTimeframeConstraint.start(), newEnd);
     calculateConflicts();
 }
 
-void ConflictResolver::setEarliestDateTime(const KDateTime &newDateTime)
+void ConflictResolver::setEarliestDateTime(const QDateTime &newDateTime)
 {
     mTimeframeConstraint = KCalCore::Period(newDateTime, mTimeframeConstraint.end());
     calculateConflicts();
 }
 
-void ConflictResolver::setLatestDateTime(const KDateTime &newDateTime)
+void ConflictResolver::setLatestDateTime(const QDateTime &newDateTime)
 {
     mTimeframeConstraint = KCalCore::Period(mTimeframeConstraint.start(), newDateTime);
     calculateConflicts();
@@ -146,7 +146,7 @@ void ConflictResolver::freebusyDataChanged()
     calculateConflicts();
 }
 
-int ConflictResolver::tryDate(KDateTime &tryFrom, KDateTime &tryTo)
+int ConflictResolver::tryDate(QDateTime &tryFrom, QDateTime &tryTo)
 {
     int conflicts_count = 0;
     for (int i = 0; i < mFBModel->rowCount(); ++i) {
@@ -169,8 +169,8 @@ int ConflictResolver::tryDate(KDateTime &tryFrom, KDateTime &tryTo)
     return conflicts_count;
 }
 
-bool ConflictResolver::tryDate(const KCalCore::FreeBusy::Ptr &fb, KDateTime &tryFrom,
-                               KDateTime &tryTo)
+bool ConflictResolver::tryDate(const KCalCore::FreeBusy::Ptr &fb, QDateTime &tryFrom,
+                               QDateTime &tryTo)
 {
     // If we don't have any free/busy information, assume the
     // participant is free. Otherwise a participant without available
@@ -180,15 +180,14 @@ bool ConflictResolver::tryDate(const KCalCore::FreeBusy::Ptr &fb, KDateTime &try
     }
 
     KCalCore::Period::List busyPeriods = fb->busyPeriods();
-    for (KCalCore::Period::List::Iterator it = busyPeriods.begin();
-         it != busyPeriods.end(); ++it) {
+    for (auto it = busyPeriods.begin(); it != busyPeriods.end(); ++it) {
         if ((*it).end() <= tryFrom     // busy period ends before try period
             || (*it).start() >= tryTo) {   // busy period starts after try period
             continue;
         } else {
             // the current busy period blocks the try period, try
             // after the end of the current busy period
-            const int secsDuration = tryFrom.secsTo(tryTo);
+            const qint64 secsDuration = tryFrom.secsTo(tryTo);
             tryFrom = (*it).end();
             tryTo = tryFrom.addSecs(secsDuration);
             // try again with the new try period
@@ -202,22 +201,22 @@ bool ConflictResolver::tryDate(const KCalCore::FreeBusy::Ptr &fb, KDateTime &try
 
 bool ConflictResolver::findFreeSlot(const KCalCore::Period &dateTimeRange)
 {
-    KDateTime dtFrom = dateTimeRange.start();
-    KDateTime dtTo = dateTimeRange.end();
+    QDateTime dtFrom = dateTimeRange.start();
+    QDateTime dtTo = dateTimeRange.end();
     if (tryDate(dtFrom, dtTo)) {
         // Current time is acceptable
         return true;
     }
 
-    KDateTime tryFrom = dtFrom;
-    KDateTime tryTo = dtTo;
+    QDateTime tryFrom = dtFrom;
+    QDateTime tryTo = dtTo;
 
     // Make sure that we never suggest a date in the past, even if the
     // user originally scheduled the meeting to be in the past.
-    KDateTime now = KDateTime::currentUtcDateTime();
+    QDateTime now = QDateTime::currentDateTimeUtc();
     if (tryFrom < now) {
         // The slot to look for is at least partially in the past.
-        const int secs = tryFrom.secsTo(tryTo);
+        const qint64 secs = tryFrom.secsTo(tryTo);
         tryFrom = now;
         tryTo = tryFrom.addSecs(secs);
     }
@@ -249,8 +248,8 @@ void ConflictResolver::findAllFreeSlots()
     // 4. locate contiguous timeslots with a values of 0. these are the free time blocks.
 
     // define these locally for readability
-    const KDateTime begin = mTimeframeConstraint.start();
-    const KDateTime end = mTimeframeConstraint.end();
+    const QDateTime begin = mTimeframeConstraint.start();
+    const QDateTime end = mTimeframeConstraint.end();
 
     // calculate the time resolution
     // each timeslot in the arrays represents a unit of time
@@ -273,7 +272,7 @@ void ConflictResolver::findAllFreeSlots()
         return;
     }
 
-    qCDebug(INCIDENCEEDITOR_LOG) << "from " << begin.dateTime() << " to " << end.dateTime()
+    qCDebug(INCIDENCEEDITOR_LOG) << "from " << begin << " to " << end
                                  << "; mSlotResolutionSeconds = " << mSlotResolutionSeconds
                                  << "; range = " << range;
     // filter out attendees for which we don't have FB data
@@ -369,7 +368,7 @@ void ConflictResolver::findAllFreeSlots()
     QVector<int> fbArray(range);
     fbArray.fill(0);   // initialize to zero
     for (int slot = 0; slot < fbArray.size(); ++slot) {
-        const KDateTime dateTime = begin.addSecs(slot * mSlotResolutionSeconds);
+        const QDateTime dateTime = begin.addSecs(slot * mSlotResolutionSeconds);
         const int dayOfWeek = dateTime.date().dayOfWeek() - 1;   // bitarray is 0 indexed
         if (!mWeekdays[dayOfWeek]) {
             fbArray[slot] = 1;
@@ -418,8 +417,8 @@ void ConflictResolver::findAllFreeSlots()
                 // convert from our timeslot interval back into to normal seconds
                 // then calculate the date times of the free block based on
                 // our initial timeframe
-                const KDateTime freeBegin = begin.addSecs(free_start_i * mSlotResolutionSeconds);
-                const KDateTime freeEnd
+                const QDateTime freeBegin = begin.addSecs(free_start_i * mSlotResolutionSeconds);
+                const QDateTime freeEnd
                     = freeBegin.addSecs((free_end_i - free_start_i) * mSlotResolutionSeconds);
                 // push the free block onto the list
                 mAvailableSlots << KCalCore::Period(freeBegin, freeEnd);
@@ -464,8 +463,8 @@ void ConflictResolver::findAllFreeSlots()
 
 void ConflictResolver::calculateConflicts()
 {
-    KDateTime start = mTimeframeConstraint.start();
-    KDateTime end = mTimeframeConstraint.end();
+    QDateTime start = mTimeframeConstraint.start();
+    QDateTime end = mTimeframeConstraint.end();
     const int count = tryDate(start, end);
     Q_EMIT conflictsDetected(count);
 
